@@ -1,29 +1,32 @@
-#' Summarise TB Burden
+#' Summarise TB Burden - By Region, Globally and for Custom Groups
 #'
 #'
 #' @description Summarise TB burden metrics by region, globally, and for custom groupings. For variables with 
 #' uncertainty represented by confidence intervals bootstrapping can be used (assuming a normal distribution) to 
 #' include this in any estimated summary measures. Currently two statistics are supported; the mean (with 
-#' 95\% confidence intervals) and the median (with 95\% interquartile range). An incidence rate and weighted proportion
-#' statistic are in development.
+#' 95\% confidence intervals) and the median (with 95\% interquartile range), rates and proportions.
 #' @param samples Numeric, the number of samples to use to generate confidence 
 #' intervals (only used when \code{conf} are present)
-#' @param compare_to_world Logical, defaults to \code{FALSE}. Should a comparision be made to 
+#' @param compare_to_world Logical, defaults to \code{TRUE}. Should a comparison be made to 
 #' the metric of interests global value.
 #' @param custom_compare Logical, defaults to \code{NULL}. A named list of custom countries.
-#' @param compare_all_regions Logical, defaults to \code{FALSE}. Should all regions be compared.
+#' @param compare_all_regions Logical, defaults to \code{TRUE}. Should all regions be compared.
 #' @param truncate_at_zero Logical, defaults to \code{TRUE}. Should lower bounds be truncated at zero?
-#' @param stat Character string, defaults to \code{"mean"}. The statistic to use to summarise the metric, currently
-#' "mean" and "median" are supported. Note "mean" and "median" do not recompute the supplied country levels values.
-#' Future options will include the weighted proportion and the summarised incidence rate.
-#' @param denominator Character string identifying the variable to use as a denominator in any proportion or rate calculation.
+#' @param stat Character string, defaults to \code{"rate"}. The statistic to use to summarise the metric, currently
+#' `"mean"`, `"median"`, `"rate"` and `"prop"` are supported. Note "mean" and "median" do not recompute the supplied 
+#' country levels values but can be used to summarise the distribution of region or global metrics. `"prop"` and`"rate"`
+#' compute the overall incidence rate for a given grouping (i.e the sum of the metric divided by the sum of the denominator).
+#' @param denom Character string defaulting to `e_pop_num` (country level population). If `stat` is set to `rate` or 
+#' `prop` then this is the parameter to use as the denominator.
+#' @param rate_scale Numeric defaults to 100,000. The scaling to use for rates. If `stat` is to set to `prop` then this defaults
+#' to 1.
 #' @inheritParams prepare_df_plot
 #' @return A tibble containing summarised values (with 95% confidence intervals) for the metric of choice
 #' stratified by area and year.
 #' @export
 #'
 #' @import magrittr
-#' @importFrom dplyr mutate group_by ungroup select select_at mutate_at funs left_join bind_rows summarise summarise_at one_of rename_at
+#' @importFrom dplyr mutate group_by ungroup select select_at mutate_at funs left_join lag bind_rows summarise summarise_at one_of rename_at arrange n contains
 #' @importFrom purrr map map2_dfr compact reduce map_lgl
 #' @importFrom tibble as_tibble
 #' @importFrom tidyr nest unnest
@@ -37,6 +40,7 @@
 #' ## Get summary of the e_mdr_pct_rr_new cases
 #' summarise_tb_burden(metric = "e_mdr_pct_rr_new",
 #'                     years =  most_recent_year,
+#'                     stat = "mean",
 #'                     samples = 100,
 #'                     compare_all_regions = TRUE,
 #'                     compare_to_world = TRUE,
@@ -62,21 +66,30 @@
 #'                     compare_to_world = TRUE, 
 #'                     compare_to_region = TRUE,
 #'                     verbose = FALSE)
+#'                     
+#'  ## Get an overview of incidence rates regionally and globally compared to the UK
+#' summarise_tb_burden(metric = "e_inc_num",
+#'                     stat = "rate",
+#'                     countries = "United Kingdom", 
+#'                     compare_to_world = TRUE, 
+#'                     compare_to_region = TRUE,
+#'                     verbose = FALSE) 
 #'}                     
 summarise_tb_burden <- function(df = NULL,
                                 dict = NULL, 
-                                metric = "e_inc_100k",
+                                metric = "e_inc_num",
                                 metric_label = NULL,
                                 conf = c("_lo", "_hi"),
                                 years = NULL,
                                 samples = 1000,
                                 countries = NULL,
                                 compare_to_region = FALSE,
-                                compare_to_world = FALSE,
+                                compare_to_world = TRUE,
                                 custom_compare = NULL,
-                                compare_all_regions = FALSE,
-                                stat = "mean",
-                                denominator = NULL,
+                                compare_all_regions = TRUE,
+                                stat = "rate",
+                                denom = "e_pop_num",
+                                rate_scale = 1e5,
                                 truncate_at_zero = TRUE,
                                 annual_change = FALSE,
                                 download_data = TRUE,
@@ -88,29 +101,44 @@ summarise_tb_burden <- function(df = NULL,
   ## Deal with undefined global function notes
   . <- NULL; Area <- NULL; Year <- NULL; country <- NULL; data <- NULL; e_pop_num <- NULL;
   g_whoregion <- NULL; id <- NULL; mean_hi <- NULL; mean_lo <- NULL; n <- NULL; pop <- NULL;
-  year <- NULL; area <- NULL;
+  year <- NULL; area <- NULL; metrics <- NULL;
+  
+  ## Set rate scale to be 1 if computing proportion
+  if (stat == "prop") {
+    rate_scale <- 1
+  }
   
   ## Set up function to compute variable summary
-  if (stat == "mean") {
-    get_summary <- function(summarised_df) {
-      summarised_df <- summarised_df %>% 
-        summarise(mean = mean(samples, na.rm = TRUE),
-                  sd = sd(samples, na.rm = TRUE)) %>% 
-        mutate(mean_lo = qnorm(0.025, mean, sd),
-               mean_hi = qnorm(0.975, mean, sd))
+  get_summary <- function(summarised_df,
+                            int_rate_scale = rate_scale,
+                            int_metrics = metrics) {
+      if (stat == "mean") {
+        summarised_df <- summarised_df %>% 
+          summarise(mean = mean(samples, na.rm = TRUE),
+                    sd = sd(samples, na.rm = TRUE)) %>% 
+          mutate(mean_lo = qnorm(0.025, mean, sd),
+                 mean_hi = qnorm(0.975, mean, sd))
+       }else if (stat == "median") {
+        summarised_df <- summarised_df %>% 
+          summarise(mean = median(samples, na.rm = TRUE),
+                    mean_lo = quantile(samples, 0.025, na.rm = TRUE),
+                    mean_hi = quantile(samples, 0.975, na.rm = TRUE))
+      } else if (stat %in% c("rate", "prop")) {
+        summarised_df <- summarised_df %>% 
+          summarise_at(.vars = c(metrics, "denom"),
+                       funs(sum(as.numeric(.), na.rm = T))) %>% 
+          mutate_at(.vars = int_metrics,
+                    .funs = funs(. / denom * int_rate_scale)) %>% 
+          select(-denom)
+        
+        
+        colnames(summarised_df) <- c("Area", "Year", paste0("mean", c("", "_lo", "_hi")))
+        
+      } else {
+        stop("This statistic is not currently supported.")
+      }
+      return(summarised_df)
     }
-    
-  }else if (stat == "median") {
-    get_summary <- function(summarised_df) {
-      summarised_df <- summarised_df %>% 
-        summarise(mean = median(samples, na.rm = TRUE),
-                  mean_lo = quantile(samples, 0.025, na.rm = TRUE),
-                  mean_hi = quantile(samples, 0.975, na.rm = TRUE))
-    }
-    
-  }else{
-    stop("This statistic is not currently supported.")
-  }
   
   if (!is.null(countries)) {
     
@@ -125,7 +153,7 @@ summarise_tb_burden <- function(df = NULL,
                                     conf = conf,
                                     countries = countries,
                                     compare_to_region = FALSE,
-                                    annual_change = annual_change,
+                                    annual_change = FALSE,
                                     download_data = download_data,
                                     save = save,
                                     burden_save_name = burden_save_name,
@@ -152,7 +180,7 @@ summarise_tb_burden <- function(df = NULL,
                                   conf = conf,
                                   countries = countries_region,
                                   compare_to_region = TRUE,
-                                  annual_change = annual_change,
+                                  annual_change = FALSE,
                                   download_data = download_data,
                                   save = save,
                                   burden_save_name = burden_save_name,
@@ -173,7 +201,7 @@ summarise_tb_burden <- function(df = NULL,
                                 conf = conf,
                                 countries = NULL,
                                 compare_to_region = FALSE,
-                                annual_change = annual_change,
+                                annual_change = FALSE,
                                 download_data = download_data,
                                 save = save,
                                 burden_save_name = burden_save_name,
@@ -207,7 +235,7 @@ summarise_tb_burden <- function(df = NULL,
                                                         conf = conf,
                                                         countries = .x,
                                                         compare_to_region = FALSE,
-                                                        annual_change = annual_change,
+                                                        annual_change = FALSE,
                                                         download_data = download_data,
                                                         save = save,
                                                         burden_save_name = burden_save_name,
@@ -221,7 +249,6 @@ summarise_tb_burden <- function(df = NULL,
     custom_group_df <- NULL
   }
   
- 
   if (compare_to_region | compare_all_regions | !is.null(custom_group_df) | compare_to_world) {
     ## Combine into a single data-set
     all_df <- list(regions_df, custom_group_df, world_df) 
@@ -251,7 +278,20 @@ summarise_tb_burden <- function(df = NULL,
       conf <- NULL
       }
     
-    if (is.null(conf)) {
+    if (stat %in% c("prop", "rate")) {
+      
+      if (!is.null(conf)) {
+        metrics <- c(metric, paste0(metric, conf))
+      }else{
+        metrics <- c(metric, paste0(metric, 1:2))
+        all_df[metrics] <- all_df[[metric]]
+      }
+
+      
+      summarised_df <- all_df %>% 
+        rename_at(.vars = denom, ~ "denom")
+     
+    } else if (is.null(conf)) {
 
       summarised_df <-  all_df %>% 
         rename_at(.vars = metric, .funs = funs(paste0("samples")))
@@ -267,7 +307,7 @@ summarise_tb_burden <- function(df = NULL,
                   .funs = funs(ifelse(is.na(.), all_df[[metric]], .))) %>% 
         group_by(Area, Year)
       
-      summarised_df$sd <- (summarised_df[[metrics[3]]] - summarised_df[[metrics[2]]]) / (2*1.96)
+      summarised_df$sd <- (summarised_df[[metrics[3]]] - summarised_df[[metrics[2]]]) / (2 * 1.96)
       
       summarised_df <- summarised_df %>%
         ungroup %>% 
@@ -307,6 +347,7 @@ summarise_tb_burden <- function(df = NULL,
     }
     
     colnames(summarised_df) <- c("area", "year", paste0(metric, c("", "_lo", "_hi")))
+    
   }else{
     summarised_df <- NULL
   }
@@ -322,14 +363,27 @@ summarise_tb_burden <- function(df = NULL,
   
  if (!is.null(countries_df)) {
    output_df <- countries_df %>% 
-     select(area = Area, year, one_of(paste0(metric, c("", "_lo", "_hi")))) 
+     select(area = Area, year, one_of(paste0(metric, c("", "_lo", "_hi"))), contains(denom)) 
    
    if (!is.null(years)) {
      output_df <- filter(output_df, year %in% years)
    }
    
+   ## Estimate rate/proportions for countries specified.
+   if (stat %in% c("rate", "prop")) {
+     output_df <- output_df %>% 
+       rename_at(.vars = denom, .funs = ~ "denom") %>% 
+       group_by(area, year) %>% 
+       get_summary() %>% 
+       ungroup %>% 
+       mutate_at(.vars = c("mean", "mean_lo", "mean_hi"),
+                 .funs = funs(ifelse(. %in% NaN, NA, .)))
+     
+     colnames(output_df) <- c("area", "year", paste0(metric, c("", "_lo", "_hi")))
+   }
+   
    if (!is.null(summarised_df)) {
-     output_df <- output_df%>% 
+     output_df <- output_df %>% 
        bind_rows(summarised_df)
    }
    
@@ -342,5 +396,25 @@ summarise_tb_burden <- function(df = NULL,
    
   output_df <- mutate(output_df, area = factor(area, levels = area_list)) 
   
+  ## Estimate annual change
+  if (annual_change) {
+    
+    if (is.null(conf)) {
+      metrics <- metric
+    }else{
+      metrics <- c(metric, paste0(metric, conf))
+    }
+    
+    output_df <- output_df %>% 
+      group_by(area) %>% 
+      arrange(year) %>% 
+      mutate_at(.vars = metrics, .funs = funs((. - lag(.)) / lag(.))) %>%
+      arrange(year) %>% 
+      slice(-1) %>% 
+      ungroup %>% 
+      mutate_at(.vars = metrics,
+                .funs = funs(replace(., is.nan(.), NA)))
+  }
+  
   return(output_df)
 }
